"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var LdapClient = require("ldapjs");
var config_1 = require("../config");
var UserCtrl = (function () {
    function UserCtrl(router) {
        router.route('/user/authorize').get(this.authorize);
        router.route('/user/login').post(this.login.bind(this));
        router.route('/user/current').get(this.current);
        router.route('/user/can').get(this.can);
    }
    UserCtrl.prototype.authorize = function (req, res) {
        // you can rewrite this function to support your own authorization logic
        // by default, doing nothing but redirection
        if (req.query.url) {
            res.redirect(req.query.url);
        }
        else {
            res.redirect('/');
        }
    };
    UserCtrl.prototype.current = function (req, res) {
        res.json(req.session.username || 'Sign In');
    };
    UserCtrl.prototype.can = function (req, res) {
        res.json(req.session.isAdmin ? true : false);
    };
    UserCtrl.prototype.login = function (req, res) {
        var credential = req.body;
        if (!credential.username || !credential.password) {
            res.status(401).json(false);
            return;
        }
        // check LDAP
        var ldap = LdapClient.createClient({ url: config_1.LDAP.uri });
        ldap.bind(credential.username + config_1.LDAP.principalSuffix, credential.password, function (err) {
            if (err) {
                res.status(401).json(false);
            }
            else {
                // authroized
                req.session.username = credential.username;
                config_1.CheckAdmin(req.session.username, function (isAdmin) {
                    req.session.isAdmin = isAdmin;
                    res.json(true);
                });
            }
        });
    };
    return UserCtrl;
}());
exports.UserCtrl = UserCtrl;
//# sourceMappingURL=user.js.map
